@@ -48,8 +48,12 @@ nitpick_ignore = [
     ('py:class', 'django.db.models.base.Model'),  # not documented upstream
     ('py:class', 'module'),  # ModuleType not documented.
     ('py:class', 'tempfile.TemporaryFile'),  # not documented as a class so type annotation broken
+    ('py:class', 'testfixtures.comparison.S'),  # type var
+    ('py:class', 'testfixtures.comparison.S_'),  # type var
+    ('py:class', 'testfixtures.comparison.T'),  # type var
     ('py:class', 'testfixtures.datetime.MockedCurrent'),  # internal class that shouldn't be doc'ed
     ('py:class', 'testfixtures.replace.R'),  # type var
+    ('py:class', 'testfixtures.shouldraise.E'),  # type var
     ('py:class', 'testfixtures.utils.T'),  # type var
     ('py:class', 'testfixtures.utils.U'),  # type var
     ('py:class', 'twisted.trial.unittest.TestCase'),  # twisted doesn't use sphinx
