@@ -1,26 +1,24 @@
 import re
 from abc import ABC
+from collections import namedtuple
 from datetime import date, datetime, time
 from decimal import Decimal
-
 from functools import partial
-
-from collections import namedtuple
-
-from testfixtures.shouldraise import ShouldAssert
-from testfixtures.tests.sample1 import SampleClassA, SampleClassB, Slotted
-from testfixtures.mock import Mock, call
 from re import compile
+from unittest import TestCase
+
 from testfixtures import (
     Comparison as C,
     Replacer,
     ShouldRaise,
     compare,
     generator,
-    singleton, mock_datetime,
+    singleton,
 )
 from testfixtures.comparison import compare_sequence, compare_object
-from unittest import TestCase
+from testfixtures.mock import Mock, call
+from testfixtures.shouldraise import ShouldAssert
+from testfixtures.tests.sample1 import Slotted
 
 hexaddr = compile('0x[0-9A-Fa-f]+')
 
@@ -770,6 +768,32 @@ class TestCompare(CompareHelper, TestCase):
             pass
         compare(TestFloat(0.75), TestFloat(0.75), strict=True)
 
+    def test_float_int_strict(self):
+        self.check_raises(
+            float(7.0), int(7),
+            "7.0 (<class 'float'>) != 7 (<class 'int'>)",
+            strict=True,
+        )
+
+    def test_bug(self):
+        self.check_raises(
+            generator(1.0),
+            generator(1),
+            'sequence not as expected:\n'
+            '\n'
+            'same:\n'
+            '()\n'
+            '\n'
+            'first:\n'
+            '(1.0,)\n'
+            '\n'
+            'second:\n'
+            '(1,)\n'
+            '\n'
+            "While comparing [0]: 1.0 (<class 'float'>) != 1 (<class 'int'>)",
+            strict=True,
+        )
+
     def test_old_style_classes_same(self):
         class X:
             pass
@@ -2133,6 +2157,15 @@ class TestCompareObject:
                 comparers={self.Thing: compare_thing},
                 ignore_attributes=['z'])
 
+    def test_strict_respected_when_nested(self):
+        with ShouldAssert(
+            "Thing not as expected:\n\n"
+            "attributes differ:\n"
+            "'x': datetime.time(0, 0) != datetime.time(0, 0, fold=1)\n\n"
+            "While comparing .x: datetime.time(0, 0) != datetime.time(0, 0, fold=1)",
+        ):
+            compare(self.Thing(x=time()), self.Thing(x=time(fold=1)), strict=True)
+
 
 class BaseClass(ABC):
     pass
@@ -2221,3 +2254,15 @@ class TestDateAndTime:
                 'datetime.time(0, 0, fold=1) != datetime.time(0, 0)'
         ):
             compare(time(fold=1), time(fold=0), strict=True)
+
+    def test_datetime_with_different_fold_strict_but_identical_repr(self):
+        class PandasDatetime(datetime):
+            def __repr__(self):
+                return f'<DT{self.year}-{self.day}-{self.month}>'
+
+        with ShouldAssert(
+                '<DT2000-1-1> (fold=1) != <DT2000-1-1> (fold=0)'
+        ):
+            compare(
+                PandasDatetime(2000, 1, 1, fold=1), PandasDatetime(2000, 1, 1, fold=0), strict=True
+            )
